summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/travel.h
diff options
context:
space:
mode:
authorharanp <haranp@c06c8d41-db1a-0410-9941-cceddc491573>2008-07-30 10:53:06 +0000
committerharanp <haranp@c06c8d41-db1a-0410-9941-cceddc491573>2008-07-30 10:53:06 +0000
commit262b8e18ed8cb58afb40a816ac0fdedfe3a7db5f (patch)
tree681a9cbb6c22669c6e8b7ab749228a3cd691a903 /crawl-ref/source/travel.h
parent51d8f1fc9cc8ed4280b9c53b135ccb0521e84889 (diff)
downloadcrawl-ref-262b8e18ed8cb58afb40a816ac0fdedfe3a7db5f.tar.gz
crawl-ref-262b8e18ed8cb58afb40a816ac0fdedfe3a7db5f.zip
Massive overhaul to move towards coord_def().
This might have introduced some bugs: I now get intermittent crashes on startup (this might have to do with the changes to special_room.) Sorry about that - committing before I need to do any more big conflict resolutions. Fixes coming later. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@6732 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/travel.h')
-rw-r--r--crawl-ref/source/travel.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/crawl-ref/source/travel.h b/crawl-ref/source/travel.h
index 752c285044..95ede43a98 100644
--- a/crawl-ref/source/travel.h
+++ b/crawl-ref/source/travel.h
@@ -82,7 +82,7 @@ bool is_traversable(dungeon_feature_type grid);
void explore_pickup_event(int did_pickup, int tried_pickup);
bool is_excluded(const coord_def &p);
-void find_travel_pos(int you_x, int you_y, char *move_x, char *move_y,
+void find_travel_pos(const coord_def& youpos, char *move_x, char *move_y,
std::vector<coord_def>* coords = NULL);
bool is_travelsafe_square(int x, int y, bool ignore_hostile = false,
@@ -109,7 +109,7 @@ void start_translevel_travel(const travel_target &pos);
void start_translevel_travel(bool prompt_for_destination = true);
-void start_travel(int x, int y);
+void start_travel(const coord_def& p);
command_type travel();
@@ -483,8 +483,9 @@ struct LevelInfo
void update(); // Update LevelInfo to be correct for the
// current level.
- // Updates/creates a StairInfo for the stair at (x, y) in grid coordinates
- void update_stair(int x, int y, const level_pos &p, bool guess = false);
+ // Updates/creates a StairInfo for the stair at stairpos in grid coordinates
+ void update_stair(const coord_def& stairpos, const level_pos &p,
+ bool guess = false);
// Clears all stair info for stairs matching this grid type.
void clear_stairs(dungeon_feature_type grid);